DSMessageBrokerProviderMetadata class

Metadata for registered message broker providers.

Constructors

DSMessageBrokerProviderMetadata({required String type, String? vendor, String? region, String? projectId, Map<String, dynamic>? additionalMetadata})
Constructor.

Properties

additionalMetadata Map<String, dynamic>?
Additional provider-specific metadata.
final
hashCode int
The hash code for this object.
no setterinherited
projectId String?
Optional project identifier.
final
region String?
Optional region information.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Provider type (e.g., pubsub).
final
vendor String?
Optional vendor name (e.g., gcp).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited