DSMessageBrokerMessage class

Standard message shape returned by message broker providers.

Constructors

DSMessageBrokerMessage({required String id, required String payload, Map<String, String> attributes = const {}, DateTime? publishTime, String? ackId})
Constructor.

Properties

ackId String?
Optional acknowledgement identifier.
final
attributes Map<String, String>
Optional attributes/headers.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Message identifier.
final
payload String
Message payload (UTF-8 string).
final
publishTime DateTime?
Optional publish timestamp.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited