DSMessageBrokerProvider class abstract

Message broker provider interface for DartStream. Defines the standard interface for all message broker providers.

Constructors

DSMessageBrokerProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acknowledge(String subscription, List<String> ackIds) Future<void>
Acknowledge received messages.
dispose() Future<void>
Dispose of the provider and release resources.
initialize(Map<String, dynamic> config) Future<void>
Initialize the provider with configuration settings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(String topic, String payload, {Map<String, String>? attributes}) Future<void>
Publish a message to a topic.
subscribe(String subscription, {int maxMessages = 10, Duration? pollInterval}) Stream<DSMessageBrokerMessage>
Subscribe to a topic or subscription stream.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited